@@ -1,10 +1,11 @@
 #
-# $Id: ICMPv4.pm,v 1.2.2.29 2006/03/11 16:32:50 gomor Exp $
+# $Id: ICMPv4.pm,v 1.2.2.31 2006/03/19 17:17:01 gomor Exp $
 #
 package Net::Packet::ICMPv4;
 
 use strict;
 use warnings;
+use Carp;
 
 require Net::Packet::Layer4;
 require Class::Gomor::Hash;
@@ -303,7 +304,7 @@ sub _unpackTimeExceed {
 
 sub _decodeError {
    my $self = shift;
-   warn("@{[(caller(0))[3]]}: unknown ICMPv4: ".
+   carp("@{[(caller(0))[3]]}: unknown ICMPv4: ".
         "type: @{[$self->type]}, code: @{[$self->code]}\n");
    undef;
 }
@@ -676,7 +677,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 Copyright (c) 2004-2006, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
-See Copying file in the source distribution archive.
+See LICENSE.Artistic file in the source distribution archive.
 
 =head1 RELATED MODULES
 
